import junit.framework.TestCase;

public class HtmlStatementTests extends TestCase {
  
  public void testStatementForRegularMovie() {
    Customer c = new Customer( "Sallie" );
    Movie    m = new Movie( "Gone with the Wind", Movie.REGULAR );
    Rental   r = new Rental( m, 3 );        // 3-day rental
    c.addRental( r );
    
    String expected = "<H1>Rental Record for <EM>Sallie</EM></H1>\n" +
      "\tGone with the Wind\t3.5<BR/>\n" +
      "<P>Amount owed is <EM>3.5</EM></P>\n" +
      "<P>You earned <EM>1 frequent renter points</EM></P>";
    String statement = c.htmlStatement();
    assertEquals( expected, statement );
  }
  
  public void testStatementForNewReleaseMovie() {
    Customer c = new Customer( "Sallie" );
    Movie    m = new Movie( "Star Wars", Movie.NEW_RELEASE );
    Rental   r = new Rental( m, 3 );        // 3-day rental
    c.addRental( r );
    
    String expected = "<H1>Rental Record for <EM>Sallie</EM></H1>\n" +
      "\tStar Wars\t9.0<BR/>\n" +
      "<P>Amount owed is <EM>9.0</EM></P>\n" +
      "<P>You earned <EM>2 frequent renter points</EM></P>";
    String statement = c.htmlStatement();
    assertEquals( expected, statement );
  }
  
  public void testStatementForChildrensMovie() {
    Customer c = new Customer( "Sallie" );
    Movie    m = new Movie( "Madagascar", Movie.CHILDRENS );
    Rental   r = new Rental( m, 3 );        // 3-day rental
    c.addRental( r );
    
    String expected = "<H1>Rental Record for <EM>Sallie</EM></H1>\n" +
      "\tMadagascar\t1.5<BR/>\n" +
      "<P>Amount owed is <EM>1.5</EM></P>\n" +
      "<P>You earned <EM>1 frequent renter points</EM></P>";
    String statement = c.htmlStatement();
    assertEquals( expected, statement );
  }
  
  public void testStatementForManyMovies() {
    Customer c  = new Customer( "David" );
    
    Movie    m1 = new Movie( "Madagascar", Movie.CHILDRENS );
    Rental   r1 = new Rental( m1, 6 );        // 6-day rental
    Movie    m2 = new Movie( "Star Wars", Movie.NEW_RELEASE );
    Rental   r2 = new Rental( m2, 2 );        // 2-day rental
    Movie    m3 = new Movie( "Gone with the Wind", Movie.REGULAR );
    Rental   r3 = new Rental( m3, 8 );        // 8-day rental
    
    c.addRental( r1 );
    c.addRental( r2 );
    c.addRental( r3 );
   
    String expected = "<H1>Rental Record for <EM>David</EM></H1>\n" +
      "\tMadagascar\t6.0<BR/>\n" +
      "\tStar Wars\t6.0<BR/>\n" +
      "\tGone with the Wind\t11.0<BR/>\n" +
      "<P>Amount owed is <EM>23.0</EM></P>\n" +
      "<P>You earned <EM>4 frequent renter points</EM></P>";
    String statement = c.htmlStatement();
    assertEquals( expected, statement );
  }
  
}
